pub struct ArtworksClient { /* private fields */ }Implementations
Sourceimpl ArtworksClient
impl ArtworksClient
Sourcepub async fn get(
&self,
request_builder: RequestBuilder,
) -> Result<Vec<Artwork>, Box<dyn Error + Send + Sync + 'static>>
pub async fn get( &self, request_builder: RequestBuilder, ) -> Result<Vec<Artwork>, Box<dyn Error + Send + Sync + 'static>>
Receives a configured RequestBuilder an returns a result containing a collection
Sourceimpl ArtworksClient
impl ArtworksClient
Sourcepub async fn download_by_id<S: Into<String>>(
&self,
id: usize,
path: S,
media_quality: MediaQuality,
) -> Result<(), Box<dyn Error + Send + Sync + 'static>>
pub async fn download_by_id<S: Into<String>>( &self, id: usize, path: S, media_quality: MediaQuality, ) -> Result<(), Box<dyn Error + Send + Sync + 'static>>
Download to the given path the resource specified in the Id MediaQuality is an enum that specifies different image sizes
Examples
use igdb_rs::client::IGDBClient;
use igdb_rs::media_quality::MediaQuality;
let client = IGDBClient::new("key");
let screenshot_client = client.screenshots();
screenshot_client.download_by_id(12400, "screen.jpg".to_string(), MediaQuality::ScreenshotHuge,);Sourcepub async fn get_resource_by_id(
&self,
id: usize,
media_quality: MediaQuality,
) -> Result<Vec<u8>, Box<dyn Error + Send + Sync + 'static>>
pub async fn get_resource_by_id( &self, id: usize, media_quality: MediaQuality, ) -> Result<Vec<u8>, Box<dyn Error + Send + Sync + 'static>>
Retrieves content in bytes for the given media resource MediaQuality is an enum that specifies different image sizes
Examples
use igdb_rs::client::IGDBClient;
use igdb_rs::media_quality::MediaQuality;
let client = IGDBClient::new("key");
let screenshot_client = client.screenshots();
screenshot_client.get_resource_by_id(12400, MediaQuality::ScreenshotHuge,);Auto Trait Implementations
impl Freeze for ArtworksClient
impl RefUnwindSafe for ArtworksClient
impl Send for ArtworksClient
impl Sync for ArtworksClient
impl Unpin for ArtworksClient
impl UnsafeUnpin for ArtworksClient
impl UnwindSafe for ArtworksClient