[−][src]Struct igdb_rs::client::CompanyClient
Methods
impl CompanyClient[src]
pub async fn get<'_>(
&'_ self,
request_builder: RequestBuilder
) -> Result<Vec<Company>, Exception>[src]
&'_ self,
request_builder: RequestBuilder
) -> Result<Vec<Company>, Exception>
Receives a configured RequestBuilder an returns a result containing a collection
pub async fn get_by_id<'_>(
&'_ self,
id: usize,
limit: usize
) -> Result<Vec<Company>, Exception>[src]
&'_ self,
id: usize,
limit: usize
) -> Result<Vec<Company>, Exception>
Returns a collection filtered by id and limits the retrieved registries using limit parameter value.
pub async fn get_first_by_id<'_>(&'_ self, id: usize) -> Option<Company>[src]
Returns the element by Id for this client in Option