[−][src]Struct igdb_rs::client::IGDBClient
Methods
impl IGDBClient[src]
pub fn artworks(&self) -> ArtworksClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn characters(&self) -> CharacterClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn companies(&self) -> CompanyClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn covers(&self) -> CoversClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn games(&self) -> GameClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn game_modes(&self) -> GameModesClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn game_videos(&self) -> GameVideosClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn game_engines(&self) -> EnginesClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn multiplayer_modes(&self) -> MultiPlayerModeClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn release_dates(&self) -> ReleaseDateClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn screenshots(&self) -> ScreenshotsClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn themes(&self) -> ThemesClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn websites(&self) -> WebsitesClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn platforms(&self) -> PlatformsClient[src]
Returns a reference to the client
impl IGDBClient[src]
pub fn new<S: Into<String>>(api_key: S) -> IGDBClient[src]
Creates a new instance of the IGDB Client To create a new instance you need to provide the user-key your are provided with when you register in the API Website
Examples
use igdb_rs::client::IGDBClient; let igdb = IGDBClient::new("user-key");
pub fn create_request() -> RequestBuilder[src]
Creates a new instance of a Request builder you can use it's methods to create custom queries
Examples
use igdb_rs::client::IGDBClient; use igdb_rs::request_builder::Equality; let mut request = IGDBClient::create_request(); request .all_fields() .add_where("id", Equality::Greater, "340") .limit(10);