pub struct PlatformLogosClient { /* private fields */ }Implementations
Sourceimpl PlatformLogosClient
impl PlatformLogosClient
Sourcepub async fn get(
&self,
request_builder: RequestBuilder,
) -> Result<Vec<PlatformLogo>, Box<dyn Error + Send + Sync + 'static>>
pub async fn get( &self, request_builder: RequestBuilder, ) -> Result<Vec<PlatformLogo>, Box<dyn Error + Send + Sync + 'static>>
Receives a configured RequestBuilder an returns a result containing a collection
Sourcepub async fn get_by_id(
&self,
id: usize,
limit: usize,
) -> Result<Vec<PlatformLogo>, Box<dyn Error + Send + Sync + 'static>>
pub async fn get_by_id( &self, id: usize, limit: usize, ) -> Result<Vec<PlatformLogo>, Box<dyn Error + Send + Sync + 'static>>
Returns a collection filtered by id and limits the retrieved registries using limit parameter value.
Sourcepub async fn get_first_by_id(
&self,
id: usize,
) -> Result<PlatformLogo, Box<dyn Error + Send + Sync + 'static>>
pub async fn get_first_by_id( &self, id: usize, ) -> Result<PlatformLogo, Box<dyn Error + Send + Sync + 'static>>
Returns the element by Id for this client in Option
Sourceimpl PlatformLogosClient
impl PlatformLogosClient
Sourcepub async fn download_by_id<S: Into<String>>(
&self,
id: usize,
path: S,
media_quality: MediaQuality,
) -> Result<(), Box<dyn Error + Send + Sync + 'static>>
pub async fn download_by_id<S: Into<String>>( &self, id: usize, path: S, media_quality: MediaQuality, ) -> Result<(), Box<dyn Error + Send + Sync + 'static>>
Download to the given path the resource specified in the Id MediaQuality is an enum that specifies different image sizes
Examples
use igdb_rs::client::IGDBClient;
use igdb_rs::media_quality::MediaQuality;
let client = IGDBClient::new("key");
let screenshot_client = client.screenshots();
screenshot_client.download_by_id(12400, "screen.jpg".to_string(), MediaQuality::ScreenshotHuge,);Sourcepub async fn get_resource_by_id(
&self,
id: usize,
media_quality: MediaQuality,
) -> Result<Vec<u8>, Box<dyn Error + Send + Sync + 'static>>
pub async fn get_resource_by_id( &self, id: usize, media_quality: MediaQuality, ) -> Result<Vec<u8>, Box<dyn Error + Send + Sync + 'static>>
Retrieves content in bytes for the given media resource MediaQuality is an enum that specifies different image sizes
Examples
use igdb_rs::client::IGDBClient;
use igdb_rs::media_quality::MediaQuality;
let client = IGDBClient::new("key");
let screenshot_client = client.screenshots();
screenshot_client.get_resource_by_id(12400, MediaQuality::ScreenshotHuge,);Auto Trait Implementations
impl Freeze for PlatformLogosClient
impl RefUnwindSafe for PlatformLogosClient
impl Send for PlatformLogosClient
impl Sync for PlatformLogosClient
impl Unpin for PlatformLogosClient
impl UnsafeUnpin for PlatformLogosClient
impl UnwindSafe for PlatformLogosClient